<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Location extends CI_Controller{
  public function index()
  {
    // Retrieve filter values from the URI
    $filters = array(
      'property_type' => $this->input->get('property_type') ? $this->input->get('property_type') : null,
      'property_status' => $this->input->get('buyrent') ? $this->input->get('buyrent') : null,
      'bedrooms' => is_numeric($this->input->get('bedrooms')) ? (int)$this->input->get('bedrooms') : null,
      'bathrooms' => is_numeric($this->input->get('bathrooms')) ? (int)$this->input->get('bathrooms') : null,
      'location' => !empty($this->input->get('location')) ? $this->input->get('location') : null,
      'min_price' => is_numeric($this->input->get('minbudget')) ? (int)$this->input->get('minbudget') : null,
      'max_price' => is_numeric($this->input->get('maxbudget')) ? (int)$this->input->get('maxbudget') : null,
    );
    // Load pagination library
    $this->load->library('pagination');
    // Get total rows based on filters (adjust the model query accordingly)
    $total_rows = $this->crud->count_filtered_properties($filters);
    // Configure pagination
    $config['base_url'] = base_url('property-list');
    $config['total_rows'] = $total_rows;
    $config['per_page'] = $this->crud->getSetting('propertyPerPage');
    $config['uri_segment'] = 2;
    // Customizing the pagination HTML
    $config['full_tag_open'] = '<div class="pagination-box text-center"><nav aria-label="Page navigation"><ul class="pagination">';
    $config['full_tag_close'] = '</ul></nav></div>';
    $config['num_tag_open'] = '<li class="page-item">';
    $config['num_tag_close'] = '</li>';
    $config['cur_tag_open'] = '<li class="page-item active"><a class="page-link" href="#">';
    $config['cur_tag_close'] = '</a></li>';
    $config['next_tag_open'] = '<li class="page-item">';
    $config['next_tag_close'] = '</li>';
    $config['prev_tag_open'] = '<li class="page-item">';
    $config['prev_tag_close'] = '</li>';
    $config['next_link'] = 'Next';
    $config['prev_link'] = 'Prev';
    $config['first_tag_open'] = '<li class="page-item">';
    $config['first_tag_close'] = '</li>';
    $config['last_tag_open'] = '<li class="page-item">';
    $config['last_tag_close'] = '</li>';
    /* Ensure page links have class */
    $config['attributes'] = array('class' => 'page-link');
    $config['use_page_numbers'] = TRUE;
    $config['page_query_string'] = FALSE;
    $config['suffix'] = '.html';
    // Initialize pagination
    $this->pagination->initialize($config);
    // Get the current page number from the query string
    $page = ($this->uri->segment(2)) ? $this->uri->segment(2) : 1;
    // Calculate the offset
    $start = ($page - 1) * $config['per_page'];
    // debug($start);

    // Fetch filtered property data
    $properties = $this->crud->get_filtered_properties($filters, $start, $config['per_page']);
    // debug($this->db->last_query());  // Output the SQL query for debugging
    // debug($properties,true);
    // Generate pagination links
    $configPage['links'] = $this->pagination->create_links();
    // Assign data to pass to the views
    $configPage['propertyList'] = $properties;
    $configPage['page'] = 'location';
    $configPage['pageTitle'] = 'All Properties & Projects List';
    // debug($configPage,true);
    // Load views
    $this->load->view('frontend/common/header', $configPage);
    $this->load->view('frontend/listing', $configPage);
    $this->load->view('frontend/common/footer');
  }
  public function locList($location=null)
  {
    if (!empty($location)) {
      $this->load->helper('text');
      $config['page'] = 'location';
      $loc = $this->crud->getDataSingle('locations', $location, 'uri', null);
      $lc = $this->crud->getCount('property', 'location', cleanVal($location));
      $config['pageTitle'] = $loc->title;

      if (isset($_GET['filter'])) {
        if (cleanVal($_GET['filter']) === 'commercial') {
          $config['prpertyList'] = $this->crud->getPropertyListByLocationAndType(cleanVal($location), 'commercial', 'DESC', null);
        }
        else if (cleanVal($_GET['filter']) === 'residential') {
          $config['prpertyList'] = $this->crud->getPropertyListByLocationAndType(cleanVal($location), 'residential', 'DESC', null);
        }else{
          $config['prpertyList'] = $this->crud->getDataSingle('property', cleanVal($location), 'location', true);
        }
      } else {
        $config['prpertyList'] = $this->crud->getDataSingle('property', cleanVal($location), 'location', true);
      }
      $config['seoTitle'] = $loc->title.' | Infinity Prop Solutions';
      $config['seoDesc'] = $loc->title.' | Infinity Prop Solutions';
      $config['seoKeys'] = $loc->title.' | Infinity Prop Solutions';
      $this->load->view('public/common/header',$config);
      $this->load->view('public/property-list');
      $this->load->view('public/common/footer');
    } else {
      $this->session->set_flashdata('type', 'error');
      $this->session->set_flashdata('title', 'Error');
      $this->session->set_flashdata('msg', 'No direct script access allowed.');
      return redirect(base_url('location.html'));
    }
  }
}
?>
