<?php
defined('BASEPATH') or exit('No direct script access allowed');
class Property extends CI_Controller
{
  function __construct()
  {
    parent::__construct();
  }
  public function index()
  {
    // Retrieve filter values from the URI
    $filters = array(
      'property_type' => $this->input->get('property_type') ? $this->input->get('property_type') : null,
      'property_status' => $this->input->get('buyrent') ? $this->input->get('buyrent') : null,
      'bedrooms' => is_numeric($this->input->get('bedrooms')) ? (int)$this->input->get('bedrooms') : null,
      'bathrooms' => is_numeric($this->input->get('bathrooms')) ? (int)$this->input->get('bathrooms') : null,
      'location' => !empty($this->input->get('location')) ? $this->input->get('location') : null,
      'min_price' => is_numeric($this->input->get('minbudget')) ? (int)$this->input->get('minbudget') : null,
      'max_price' => is_numeric($this->input->get('maxbudget')) ? (int)$this->input->get('maxbudget') : null,
    );
    // Load pagination library
    $this->load->library('pagination');
    // Get total rows based on filters (adjust the model query accordingly)
    $total_rows = $this->crud->count_filtered_properties($filters);
    // Configure pagination
    $config['base_url'] = base_url('property-list');
    $config['total_rows'] = $total_rows;
    $config['per_page'] = $this->crud->getSetting('propertyPerPage');
    $config['uri_segment'] = 2;
    // Customizing the pagination HTML
    $config['full_tag_open'] = '<div class="pagination-box text-center"><nav aria-label="Page navigation"><ul class="pagination">';
    $config['full_tag_close'] = '</ul></nav></div>';
    $config['num_tag_open'] = '<li class="page-item">';
    $config['num_tag_close'] = '</li>';
    $config['cur_tag_open'] = '<li class="page-item active"><a class="page-link" href="#">';
    $config['cur_tag_close'] = '</a></li>';
    $config['next_tag_open'] = '<li class="page-item">';
    $config['next_tag_close'] = '</li>';
    $config['prev_tag_open'] = '<li class="page-item">';
    $config['prev_tag_close'] = '</li>';
    $config['next_link'] = 'Next';
    $config['prev_link'] = 'Prev';
    $config['first_tag_open'] = '<li class="page-item">';
    $config['first_tag_close'] = '</li>';
    $config['last_tag_open'] = '<li class="page-item">';
    $config['last_tag_close'] = '</li>';
    /* Ensure page links have class */
    $config['attributes'] = array('class' => 'page-link');
    $config['use_page_numbers'] = TRUE;
    $config['page_query_string'] = FALSE;
    $config['suffix'] = '.html';
    // Initialize pagination
    $this->pagination->initialize($config);
    // Get the current page number from the query string
    $page = ($this->uri->segment(2)) ? $this->uri->segment(2) : 1;
    // Calculate the offset
    $start = ($page - 1) * $config['per_page'];
    // debug($start);

    // Fetch filtered property data
    $properties = $this->crud->get_filtered_properties($filters, $start, $config['per_page']);
    // debug($this->db->last_query());  // Output the SQL query for debugging
    // debug($properties,true);
    // Generate pagination links
    $configPage['links'] = $this->pagination->create_links();
    // Assign data to pass to the views
    $configPage['propertyList'] = $properties;
    $configPage['page'] = 'property';
    $configPage['pageTitle'] = 'All Properties & Projects List';
    // debug($configPage,true);
    // Load views
    $this->load->view('frontend/common/header', $configPage);
    $this->load->view('frontend/listing', $configPage);
    $this->load->view('frontend/common/footer');
  }
  public function propertyDetails($uri = null)
  {
    if (!empty($uri) && $this->crud->getCount('property', 'uri', cleanVal($uri)) > 0) {
      $this->load->helper('text');
      $config['page'] = 'residential';
      $config['prp'] = $this->crud->getDataSingle('property', cleanVal($uri), 'uri', null);
      $config['seoTitle'] = $config['prp']->title . ' | Accel';
      $config['seoDesc'] = $config['prp']->title . ' | Accel';
      $config['seoKeys'] = $config['prp']->title . ' , Accel';
      $this->load->view('frontend/common/header', $config);
      $this->load->view('frontend/listing-data');
      $this->load->view('frontend/common/footer');
    } else {
      $this->session->set_flashdata('type', 'error');
      $this->session->set_flashdata('title', 'Error');
      $this->session->set_flashdata('msg', 'No direct script access allowed.');
      return redirect(base_url());
    }
  }


  public function downloadPropertyAttachment()
  {
    if ($this->input->server('REQUEST_METHOD') === 'POST') {
      if (!empty($this->input->post('name')) && !empty($this->input->post('phone')) && !empty($this->input->post('email')) && !empty($this->input->post('message'))) {
        $data['pid'] = $this->input->post('pid');
        $data['name'] = $this->input->post('name');
        $data['phone'] = $this->input->post('phone');
        $data['email'] = $this->input->post('email');
        $data['message'] = $this->input->post('message');
        $data['type'] = 'pa';
        $data['status'] = 'unread';
        $data['created'] = date('Y-m-d H:i:s');
        if ($this->crud->save('records', $data, null)) {
          echo 'saved';
        } else {
          echo 'error';
        }
      } else {
        echo 'empty';
      }
    } else {
      $this->session->set_flashdata('type', 'error');
      $this->session->set_flashdata('title', 'Error');
      $this->session->set_flashdata('msg', 'No direct script access allowed.');
      return redirect(base_url());
    }
  }
  public function talkToOurExpert()
  {
    if ($this->input->server('REQUEST_METHOD') === 'POST') {
      if (!empty($this->input->post('texp_name')) && !empty($this->input->post('texp_phone')) && !empty($this->input->post('texp_email')) && !empty($this->input->post('texp_message'))) {
        $uri = hashed($this->input->post('ru'), 'd');
        $data['pid'] = $this->input->post('pid');
        $data['name'] = $this->input->post('texp_name');
        $data['phone'] = $this->input->post('texp_phone');
        $data['email'] = $this->input->post('texp_email');
        $data['message'] = $this->input->post('texp_message');
        $data['type'] = 'expert';
        $data['status'] = 'unread';
        $data['created'] = date('Y-m-d H:i:s');
        if ($this->crud->save('records', $data, null)) {
          $this->session->set_flashdata('type', 'success');
          $this->session->set_flashdata('title', 'Message Sent!');
          $this->session->set_flashdata('msg', 'The message has been sent to the our expert.');
        } else {
          $this->session->set_flashdata('type', 'error');
          $this->session->set_flashdata('title', 'Error Occured!');
          $this->session->set_flashdata('msg', 'Unable to process your request!');
        }
      } else {
        $this->session->set_flashdata('type', 'warning');
        $this->session->set_flashdata('title', 'Required Fields!');
        $this->session->set_flashdata('msg', 'Please fill out all required fields!');
      }
      return redirect(base_url('property/' . $uri . '.html'));
    } else {
      $this->session->set_flashdata('type', 'error');
      $this->session->set_flashdata('title', 'Error');
      $this->session->set_flashdata('msg', 'No direct script access allowed.');
      return redirect(base_url());
    }
  }
  public function getData()
  {
    $filters = $this->input->post();
    $properties = $this->crud->getFilteredProperties($filters);
    if (!empty($properties)) {
      foreach ($properties as $prp){
        $addressData = $this->crud->getDataSingle('locations', $prp->location, 'uri', null)->title;
        if (!empty($prp->cover_photo)) {
          $imgPath = $prp->cover_photo;
        } else {
          $imgPath = 'upload/cover-photo/buildingbg.jpg';
        }
        echo '<!-- Property start -->';
        echo '<div class="property row g-0 fp2 clearfix wow fadeInUp delay-03s" style="visibility: visible; animation-name: fadeInUp;">';
        echo '<div class="col-lg-5 col-md-5 col-sm-12">';
        echo '<!-- Property img -->';
        echo '<a href="'.base_url('property/' . $prp->uri . '.html').'">';
        echo '<div class="property-img">';
        if (!empty($prp->price)){
          echo '<div class="property-price">';
          echo $this->crud->getSetting('currencySymbol').' '.convert_currency($prp->price).'</div>';
        }
        echo '<img src="'.base_url($imgPath).'" alt="fp-list" class="img-responsive hp-1">';
        echo '</div>';
        echo '</a>';
        echo '</div>';
        echo '<div class="col-lg-7 col-md-7 col-sm-12 property-content">';
        echo '<div class="info">';
        echo '  <!-- title -->';
        echo '<h1 class="title">';
        echo '<a href="'.base_url('property/' . $prp->uri . '.html').'">'.strtoupper($prp->title).'</a>';
        echo '</h1>';
        echo '<!-- Property address -->';
        echo '<h3 class="property-address">';
        echo '<a href="'.base_url('property/' . $prp->uri . '.html').'">';
        echo '<i class="fa fa-map-marker"></i> '.$addressData;
        echo '</a>';
        echo '</h3>';
        echo '<!-- Facilities List -->';
        echo '<ul class="facilities-list clearfix">';
        if (!empty($prp->property_size)){
          echo '<li>';
          echo '<i class="flaticon-square-layouting-with-black-square-in-east-area"></i>';
          echo '<span>';
          echo 'Sq Ft: '.$prp->property_size;
          echo '</span>';
          echo '</li>';
        }
        if (!empty($prp->bedrooms)){
          echo '<li>';
          echo '<i class="flaticon-bed"></i>';
          echo '<span>'.$prp->bedrooms.' Bedrooms</span>';
          echo '</li>';
        }
        if (!empty($prp->project_type)){
          echo '<li>';
          echo '<i class="flaticon-shape"></i>';
          echo '<span>'.ucwords($prp->project_type).'</span>';
          echo '</li>';
        }
        if (!empty($prp->bedrooms)){
          echo '<li>';
          echo '<i class="flaticon-holidays"></i>';
          echo '<span> '.$prp->bathrooms.' Bathrooms</span>';
          echo '</li>';
        }
        if (!empty($prp->garage)){
          echo '<li>';
          echo '<i class="flaticon-vehicle"></i>';
          echo '<span>'.$prp->garage.' Garage</span>';
          echo '</li>';
        }
        if (!empty($prp->property_type)){
          echo '<li>';
          echo '<i class="flaticon-apartment"></i>';
          echo '<span> '.ucwords(strtolower($prp->property_type)).'</span>';
          echo '</li>';
        }
        echo '</ul>';
        echo '<!-- Property footer -->';
        echo '</div>';
        echo '<div class="property-footer">';
        echo '<span class="left">';
        echo '<a href="'.base_url('property/' . $prp->uri . '.html').'"><i class="fa fa-user"></i>Accel</a>';
        echo '</span>';
        echo '<span class="right">';
        echo '<i class="fa fa-calendar"></i> '.daysago($prp->created);
        echo '</span>';
        echo '</div>';
        echo '</div>';
        echo '</div>';
        echo '<!-- Property end -->';
      }
    }
  }
  public function processBooking()
  {
    if ($this->input->server('REQUEST_METHOD') === 'POST') {
      if (!empty($this->input->post('datetime')) && !empty($this->input->post('subject')) && !empty($this->input->post('name')) && !empty($this->input->post('phone')) && !empty($this->input->post('email'))) {
        $uri = hashed($this->input->post('ru'), 'd');
        $data['pid'] = hashed($this->input->post('pid'),'d');
        $data['datetime'] = $this->input->post('datetime');
        $data['subject'] = $this->input->post('subject');
        $data['name'] = $this->input->post('name');
        $data['email'] = $this->input->post('email');
        $data['phone'] = $this->input->post('phone');
        $data['line_id'] = $this->input->post('line_id') ?? null;
        $data['address'] = $this->input->post('phone') ?? null;
        $data['created'] = date('Y-m-d H:i:s');
        if ($this->crud->save('bookings', $data, null)) {
          $this->session->set_flashdata('type', 'success');
          $this->session->set_flashdata('title', 'Request Sent!');
          $this->session->set_flashdata('msg', 'The appointment request has been sent to the our expert.');
        } else {
          $this->session->set_flashdata('type', 'error');
          $this->session->set_flashdata('title', 'Error Occured!');
          $this->session->set_flashdata('msg', 'Unable to process your request!');
        }
      } else {
        $this->session->set_flashdata('type', 'warning');
        $this->session->set_flashdata('title', 'Required Fields!');
        $this->session->set_flashdata('msg', 'Please fill out all required fields!');
      }
      return redirect($uri);
    } else {
      $this->session->set_flashdata('type', 'error');
      $this->session->set_flashdata('title', 'Error');
      $this->session->set_flashdata('msg', 'No direct script access allowed.');
      return redirect(base_url());
    }
  }
}
