<?php defined('BASEPATH') or exit('No direct scripts access allowed.');
if(!function_exists('daysago'))
{
  function daysago($datetime, $full = false)
  {
    $now = new DateTime;
    $ago = new DateTime($datetime);
    $diff = $now->diff($ago);
    $diff->w = floor($diff->d / 7);
    $diff->d -= $diff->w * 7;
    $string = array(
      'y' => 'year',
      'm' => 'month',
      'w' => 'week',
      'd' => 'day',
      'h' => 'hour',
      'i' => 'minute',
      's' => 'second',
    );
    foreach ($string as $k => &$v) {
      if ($diff->$k) {
        $v = $diff->$k . ' ' . $v . ($diff->$k > 1 ? 's' : '');
      } else {
        unset($string[$k]);
      }
    }
    if (!$full) $string = array_slice($string, 0, 1);
    return $string ? implode(', ', $string) . ' ago' : 'just now';
  }
  function daysleft($date)
  {
    $future = strtotime($date);
    $now = time();
    $timeleft = $future-$now;
    $daysleft = round((($timeleft/24)/60)/60);
    return $daysleft;
  }
  function cleanVal($value = '', $option = null)
  {
    $value = trim($value);
    // if (get_magic_quotes_gpc()) { $value = stripslashes($value); }
    $value = strtr($value,array_flip(get_html_translation_table(HTML_ENTITIES)));
    $value = strip_tags($value);
    // $value = mysqli_real_escape_string(get_mysqli(), $value);
    $value = htmlspecialchars($value);
    if($option != null)
    {
      if ($option == 'int') {
        $value = filter_var($value, FILTER_SANITIZE_NUMBER_INT);
      }
      else if($option == 'str')
      {
        $value = filter_var($value, FILTER_SANITIZE_STRING);
      }
      else if($option == 'email')
      {
        $value = filter_var($value, FILTER_SANITIZE_EMAIL);
      }
    }
    return $value;
  }
  function debug($array, $exit = false)
  {
    echo '<pre>';
    if ($exit === 'var')
    {
      var_dump($array);
    }
    else
    {
      print_r($array);
    }
    echo '</pre>';
    if($exit)
    {
      exit;
    }
  }
  function getBrowser($user_agent)
  {
    // Make case insensitive.
    $t = strtolower($user_agent);
    // If the string *starts* with the string, strpos returns 0 (i.e., FALSE). Do a ghetto hack and start with a space.
    // "[strpos()] may return Boolean FALSE, but may also return a non-Boolean value which evaluates to FALSE."
    //     http://php.net/manual/en/function.strpos.php
    $t = " " . $t;
    // Humans / Regular Users
    if     (strpos($t, 'opera'     ) || strpos($t, 'opr/')     ) return '<i class="fab fa-opera"></i> Opera'            ;
    elseif (strpos($t, 'edge'      )                           ) return '<i class="fab fa-edge"></i> Edge'             ;
    elseif (strpos($t, 'chrome'    )                           ) return '<i class="fab fa-chrome"></i> Chrome'           ;
    elseif (strpos($t, 'safari'    )                           ) return '<i class="fab fa-safari"></i> Safari'           ;
    elseif (strpos($t, 'firefox'   )                           ) return '<i class="fab fa-firefox"></i> Firefox'          ;
    elseif (strpos($t, 'msie'      ) || strpos($t, 'trident/7')) return '<i class="fab fa-internet-explorer"></i> Internet Explorer';
    // Search Engines
    elseif (strpos($t, 'google'    )                           ) return '[Bot] Googlebot'   ;
    elseif (strpos($t, 'bing'      )                           ) return '[Bot] Bingbot'     ;
    elseif (strpos($t, 'slurp'     )                           ) return '[Bot] Yahoo! Slurp';
    elseif (strpos($t, 'duckduckgo')                           ) return '[Bot] DuckDuckBot' ;
    elseif (strpos($t, 'baidu'     )                           ) return '[Bot] Baidu'       ;
    elseif (strpos($t, 'yandex'    )                           ) return '[Bot] Yandex'      ;
    elseif (strpos($t, 'sogou'     )                           ) return '[Bot] Sogou'       ;
    elseif (strpos($t, 'exabot'    )                           ) return '[Bot] Exabot'      ;
    elseif (strpos($t, 'msn'       )                           ) return '[Bot] MSN'         ;
    // Common Tools and Bots
    elseif (strpos($t, 'mj12bot'   )                           ) return '[Bot] Majestic'     ;
    elseif (strpos($t, 'ahrefs'    )                           ) return '[Bot] Ahrefs'       ;
    elseif (strpos($t, 'semrush'   )                           ) return '[Bot] SEMRush'      ;
    elseif (strpos($t, 'rogerbot'  ) || strpos($t, 'dotbot')   ) return '[Bot] Moz or OpenSiteExplorer';
    elseif (strpos($t, 'frog'      ) || strpos($t, 'screaming')) return '[Bot] Screaming Frog';
    // Miscellaneous
    elseif (strpos($t, 'facebook'  )                           ) return '[Bot] Facebook'     ;
    elseif (strpos($t, 'pinterest' )                           ) return '[Bot] Pinterest'    ;
    // Check for strings commonly used in bot user agents
    elseif (strpos($t, 'crawler' ) || strpos($t, 'api'    ) ||
    strpos($t, 'spider'  ) || strpos($t, 'http'   ) ||
    strpos($t, 'bot'     ) || strpos($t, 'archive') ||
    strpos($t, 'info'    ) || strpos($t, 'data'   )    ) return '[Bot] Other'   ;
    return 'Other (Unknown)';
  }
  function getOS($user_agent)
  {
    $os_platform    =   '<i class="far fa-question-circle"></i> Unknown';
    $os_array       =   array(
      '/windows nt 10/i'      =>  '<i class="fab fa-windows"></i> Windows 10',
      '/windows nt 6.3/i'     =>  '<i class="fab fa-windows"></i> Windows 8.1',
      '/windows nt 6.2/i'     =>  '<i class="fab fa-windows"></i> Windows 8',
      '/windows nt 6.1/i'     =>  '<i class="fab fa-windows"></i> Windows 7',
      '/windows nt 6.0/i'     =>  '<i class="fab fa-windows"></i> Windows Vista',
      '/windows nt 5.2/i'     =>  '<i class="fab fa-windows"></i> Windows Server 2003/XP x64',
      '/windows nt 5.1/i'     =>  '<i class="fab fa-windows"></i> Windows XP',
      '/windows xp/i'         =>  '<i class="fab fa-windows"></i> Windows XP',
      '/windows nt 5.0/i'     =>  '<i class="fab fa-windows"></i> Windows 2000',
      '/windows me/i'         =>  '<i class="fab fa-windows"></i> Windows ME',
      '/win98/i'              =>  '<i class="fab fa-windows"></i> Windows 98',
      '/win95/i'              =>  '<i class="fab fa-windows"></i> Windows 95',
      '/win16/i'              =>  '<i class="fab fa-windows"></i> Windows 3.11',
      '/macintosh|mac os x/i' =>  '<i class="fab fa-apple"></i> Mac OS X',
      '/mac_powerpc/i'        =>  '<i class="fab fa-apple"></i> Mac OS 9',
      '/linux/i'              =>  '<i class="fab fa-linux"></i> Linux',
      '/ubuntu/i'             =>  '<i class="fab fa-ubuntu"></i> Ubuntu',
      '/iphone/i'             =>  '<i class="fas fa-mobile-alt"></i> iPhone',
      '/ipod/i'               =>  '<i class="fas fa-compact-disc"></i> iPod',
      '/ipad/i'               =>  '<i class="fas fa-tablet-alt"></i> iPad',
      '/android/i'            =>  '<i class="fab fa-android"></i> Android',
      '/blackberry/i'         =>  '<i class="fab fa-blackberry"></i> BlackBerry',
      '/webos/i'              =>  '<i class="fas fa-mobile"></i> Mobile'
    );
    foreach ($os_array as $regex => $value)
    {
      if (preg_match($regex, $user_agent))
      {
        $os_platform    =   $value;
      }
    }
    return $os_platform;
  }
  function getTitle($url = null) {
    // Extract HTML using curl
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_HEADER, 0);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_FOLLOWLOCATION, 1);
    $data = curl_exec($ch);
    curl_close($ch);
    // Load HTML to DOM Object
    $dom = new DOMDocument();
    @$dom->loadHTML($data);
    // Parse DOM to get Title
    $nodes = $dom->getElementsByTagName('title');
    $title = $nodes->item(0)->nodeValue;
    return $title;
  }
  function reArrayFiles(&$file_post) {
    $file_ary = array();
    $file_count = sizeof($file_post['name']);
    $file_keys = array_keys($file_post);
    for ($i=0; $i<$file_count; $i++) {
      foreach ($file_keys as $key) {
        $file_ary[$i][$key] = $file_post[$key][$i];
      }
    }
    return $file_ary;
  }
  function hmn($number)
  {
    return substr($number, 0, 2) . '******' . substr($number, -2);
  }
  function r2p($rupee){
    return $rupee*100;
  }
  function cu($string){
    $slug=preg_replace('/[^A-Za-z0-9-]+/', '-', $string);
    return $slug;
  }
  function convert_currency($amount_in_crore) {
    // Check if the amount in crore is less than 1 crore
    if ($amount_in_crore < 1) {
      // Convert to lakhs
      $converted_amount = $amount_in_crore * 100;
      return number_format($converted_amount, 0) . ' Lakh';
    } else {
      // Keep in crores
      return number_format($amount_in_crore, 0) . ' Crore';
    }
  }
}

if (!function_exists('extract_map_url')) {
    /**
     * Extract Google Map URL from iframe embed code
     *
     * @param string $embed_code The iframe embed code
     * @return string|null The extracted URL or null if not found
     */
    function extract_map_url($embed_code) {
        // Use regex to find the src URL inside the iframe tag
        preg_match('/src="([^"]+)"/', $embed_code, $matches);

        // Return the URL if found, otherwise null
        return $matches[1] ?? null;
    }
}

?>
