<?php
class Crud extends CI_Model
{
	public function getDataAll($table, $orderByCol = null, $order = null, $limit = null)
	{
		$this->db->from($table);
		if (isset($orderByCol) && isset($order)) {
			$this->db->order_by($orderByCol, $order);
		}
		if ($limit != null) {
			$this->db->limit($limit);
		}
		$query = $this->db->get();
		$result = $query->result();
		return $result;
	}
	public function getFilteredProperties($filters) {
		$this->db->select('*');
		$this->db->from('property');
		// Applying search filter
		if (!empty(cleanVal($filters['search']))) {
			$search_query = trim($this->db->escape_str(cleanVal($filters['search'])));
			$this->db->group_start();
			$this->db->like('title', $search_query);
			$this->db->or_like('description', $search_query);
			$this->db->or_like('location', $search_query);
			$this->db->or_like('property_id', $search_query);
			$this->db->or_like('price', $search_query);
			$this->db->or_like('property_size', $search_query);
			$this->db->or_like('year_built', $search_query);
			$this->db->or_like('bedrooms', $search_query);
			$this->db->or_like('bathrooms', $search_query);
			$this->db->or_like('garage', $search_query);
			$this->db->or_like('garage_size', $search_query);
			$this->db->or_like('project_type', $search_query);
			$this->db->or_like('property_type', $search_query);
			$this->db->or_like('property_status', $search_query);
			$this->db->or_like('deposit', $search_query);
			$this->db->or_like('last_remodel_year', $search_query);
			$this->db->or_like('pool_size', $search_query);
			$this->db->or_like('amenities', $search_query);
			$this->db->or_like('places_nearby', $search_query);
			$this->db->or_like('additional_rooms', $search_query);
			$this->db->or_like('equipment', $search_query);
			$this->db->or_like('for_status', $search_query);
			$this->db->or_like('ready_to_move', $search_query);
			$this->db->or_like('balcony', $search_query);
			$this->db->or_like('video', $search_query);
			$this->db->group_end();
		}
		// Applying filters
		if (!empty($filters['ps'])) {
			$this->db->where('property_status', $filters['ps']);
		}
		if (!empty($filters['ln'])) {
			$this->db->where('location', $filters['ln']);
		}
		if (!empty($filters['pt'])) {
			$this->db->where('project_type', $filters['pt']);
		}
		if (!empty($filters['bd'])) {
			$this->db->where('bedrooms', $filters['bd']);
		}
		if (!empty($filters['bt'])) {
			$this->db->where('bathrooms', $filters['bt']);
		}
		if (!empty($filters['bl'])) {
			$this->db->where('balcony', $filters['bl']);
		}
		if (!empty($filters['gr'])) {
			$this->db->where('garage', $filters['gr']);
		}
		// Applying area filters with defaults
		$min_area = isset($filters['min_area']) ? $filters['min_area'] : 0;
		$max_area = isset($filters['max_area']) ? $filters['max_area'] : 10000;
		$this->db->where('property_size >=', (int)$min_area);
		$this->db->where('property_size <=', (int)$max_area);
		// Applying price filters with defaults
		$min_price = isset($filters['min_price']) ? $filters['min_price'] : 0;
		$max_price = isset($filters['max_price']) ? $filters['max_price'] : 150000;
		$this->db->where('price >=', (float)$min_price);
		$this->db->where('price <=', (float)$max_price);
		// Pagination
		if (isset($filters['start'])) {
			$this->db->limit(6, (int)$filters['start']);
		} else {
			$this->db->limit(6, 0);
		}
		$query = $this->db->get();
		if (!$query) {
			// Handle error
			log_message('error', $this->db->last_query());
			echo $this->db->error();
			return false;
		}
		return $query->result();
	}
	/* create modal function getProperty($start, $page) */
	public function getProperty($start, $limit, $dataStrings = null, $type='get') {
		$this->db->from('property');
		if (!empty($dataStrings)) {
			if (!empty($dataStrings['project_type'])) {
				$this->db->where('project_type', $dataStrings['project_type']);
			}
			if (!empty($dataStrings['property_status'])) {
				$this->db->or_where('property_status', $dataStrings['property_status']);
			}
			if (!empty($dataStrings['location'])) {
				$this->db->or_where('location', $dataStrings['location']);
			}
			if (!empty($dataStrings['bedrooms'])) {
				$this->db->or_where('bedrooms', $dataStrings['bedrooms']);
			}
			if (!empty($dataStrings['bathrooms'])) {
				$this->db->or_where('bathrooms', $dataStrings['bathrooms']);
			}
			if (!empty($dataStrings['balcony'])) {
				$this->db->or_where('balcony', $dataStrings['balcony']);
			}
			if (!empty($dataStrings['garage'])) {
				$this->db->or_where('garage', $dataStrings['garage']);
			}
			if (!empty($dataStrings['min_area'])) {
				$this->db->or_where('property_size >=', $dataStrings['min_area']);
			}
			if (!empty($dataStrings['max_area'])) {
				$this->db->or_where('property_size <=', $dataStrings['max_area']);
			}
			if (!empty($dataStrings['min_price'])) {
				$this->db->or_where('price >=', $dataStrings['min_price']);
			}
			if (!empty($dataStrings['max_price'])) {
				$this->db->or_where('price <=', $dataStrings['max_price']);
			}
		}
		if ($type == 'count') {
			return $this->db->count_all_results();
		} else {
			$this->db->order_by('id', 'DESC');
			$this->db->limit($limit, $start);
			$query = $this->db->get();
			// debug($this->db->last_query());
			return $query->result();
		}
	}
	public function getUnreadMails($limit)
	{
		$this->db->from('message');
		$this->db->where('status', 'unread');
		$this->db->order_by('id', 'DESC');
		$this->db->limit($limit);
		$query = $this->db->get();
		return $query->result();
	}
	public function getFeaturedPropertyList($limit)
	{
		$this->db->from('property');
		$this->db->where('featured_properties', 'yes');
		$this->db->order_by('id', 'DESC');
		$this->db->limit($limit);
		$query = $this->db->get();
		return $query->result();
	}
	public function getPropertyList($type = null, $order = null, $limit = null, $forStatus = null)
	{
		$this->db->from('property');
		if (!empty($type)) {
			$this->db->where('project_type', $type);
		}
		if (!empty($forStatus)) {
			$this->db->where('property_status', $forStatus);
		}
		if (!empty($order)) {
			$this->db->order_by('id', $order);
		}
		if (!empty($limit)) {
			$this->db->limit($limit);
		}
		$query = $this->db->get();
		return $query->result();
	}
	public function getPropertyListByLocationAndType($location = null, $filter = null, $order = null, $limit = null)
	{
		$this->db->from('property');
		if (!empty($location)) {
			$this->db->where('location', $location);
		}
		if (!empty($filter)) {
			$this->db->where('project_type', $filter);
		}
		if (!empty($order)) {
			$this->db->order_by('id', $order);
		}
		if (!empty($limit)) {
			$this->db->limit($limit);
		}
		$query = $this->db->get();
		return $query->result();
	}
	public function getAllCategoryPosts($curi, $limit = null)
	{
		$this->db->from('blog_post');
		$this->db->where('cat_uri', $curi);
		$this->db->order_by('id', 'DESC');
		if (!empty($limit)) {
			$this->db->limit($limit);
		}
		$query = $this->db->get();
		return $query->result();
	}
	public function getAllComments($pid, $status = 'published', $rcid = null)
	{
		$this->db->from('blog_comment');
		$this->db->where('post_id', $pid);
		if (!empty($rcid)) {
			$this->db->where('reply_parent_id', $rcid);
		}
		$this->db->where('status', $status);
		$this->db->order_by('id', 'DESC');
		$query = $this->db->get();
		return $query->result();
	}
	public function getPostCommentCount($pid, $status = 'published')
	{
		return $this->db->where('post_id', $pid)->where('status', $status)->count_all_results('blog_comment');
	}
	public function getUniqueAll($table, $colName = null, $orderByCol = null, $order = null)
	{
		$this->db->select('*');
		if (isset($colName)) {
			$this->db->group_by($colName);
		}
		$this->db->from($table);
		if (isset($orderByCol) && isset($order)) {
			$this->db->order_by($orderByCol, $order);
		}
		$query = $this->db->get();
		return $query->result();
	}
	public function getDataSingle($table, $id, $idname = null, $all = null, $pageName = null, $location_city = null)
	{
		$this->db->from($table);
		if ($pageName != null) {
			$this->db->where('pageName', $pageName);
		}
		if ($idname != null) {
			$this->db->where($idname, $id);
		} else {
			$this->db->where('id', $id);
		}
		if ($location_city != null) {
			$this->db->like('product_delivery_locations', $location_city, 'both');
		}
		$query = $this->db->get();
		if ($all == true) {
			$result = $query->result();
		} else {
			$result = $query->row();
		}
		return $result;
	}
	public function getUsersList($list = null, $status = null)
	{
		$this->db->from('subscribers');
		$this->db->where('list', $list);
		$this->db->where('status', $status);
		$query = $this->db->get();
		return $query->result();
	}
	public function getSetting($settingName)
	{
		$this->db->from('settings');
		$this->db->where('name', $settingName);
		$query = $this->db->get();
		return $query->row()->value;
	}
	public function save($table, $data, $getId = null)
	{
		if ($this->db->insert($table, $data)) {
			if ($getId == true) {
				return $this->db->insert_id();
			} else if ($getId == false) {
				return true;
			}
		} else {
			return false;
		}
	}
	public function save_batch($table, $data)
	{
		if ($this->db->insert_batch($table, $data)) {
			return true;
		} else {
			return false;
		}
	}
	public function update($table, $idkey, $id, $data)
	{
		$this->db->where($idkey, $id);
		if ($this->db->update($table, $data)) {
			return true;
		} else {
			return false;
		}
	}
	public function delete($table, $idkey, $id)
	{
		$this->db->where($idkey, $id);
		if ($this->db->delete($table)) {
			return true;
		} else {
			return false;
		}
	}
	public function deleteAll($table)
	{
		if ($this->db->empty_table($table)) {
			return true;
		} else {
			return false;
		}
	}
	public function delete_file($file_path)
	{
		if (file_exists($file_path)) {
			unlink($file_path);
			return true;
		} else if ($file_path === 'default') {
			return true;
		} else {
			return false;
		}
	}
	public function save_upload($title, $image)
	{
		$data = array(
			'title'     => $title,
			'file'      => $image
		);
		$result = $this->db->insert('media', $data);
		return $result;
	}
	public function getCountAll($table)
	{
		return $this->db->count_all($table);
	}
	public function getCountAllUnique($table, $colName)
	{
		$this->db->group_by($colName);
		$this->db->from($table);
		return $this->db->count_all_results();
	}
	public function getMatchedCount($table, $query, $colName)
	{
		// $this->db->group_by($colName);
		$this->db->from($table);
		$this->db->like($colName, $query, 'both');
		return $this->db->count_all_results();
	}
	public function getMatchedCatCount($catId)
	{
		$this->db->from('cause');
		$this->db->like('cat_id', $catId, 'both');
		return $this->db->count_all_results();
	}
	public function getCount($table, $colName, $colVal)
	{
		return $this->db->where($colName, $colVal)->count_all_results($table);
	}
	public function getCountUser($table, $email, $password)
	{
		return $this->db->where('email', $email)->where('password', $password)->count_all_results($table);
	}
	public function getCountGalleryItem($pid, $type)
	{
		return $this->db->where('pid', $pid)->where('type', $type)->count_all_results('gallery');
	}
	public function checkUserLoginStatus($table, $email, $opt = null)
	{
		$this->db->from($table);
		$this->db->where('email_id', $email);
		if ($opt === 'em') { //check email
			$this->db->where('email_id_status', 'active');
		}
		if ($opt === 's') { //check status
			$this->db->where('status', 'active');
		}
		if ($opt === 'fs') { // check final status
			$this->db->where('final_status', 'active_user');
		}
		if ($opt === 'rgc') { // check review gc members
			$this->db->where('for_review_gc_member', 'yes');
		}
		if ($opt === 'ra') { // check review admin
			$this->db->where('for_review_admin', 'yes');
		}
		return $this->db->count_all_results();
	}
	public function checkSU($username, $password)
	{
		return $this->db->where('username', $username)->where('password', $password)->count_all_results('su');
	}
	public function slog($title, $cid, $type)
	{
		$data['title'] = $title;
		$data['cid'] = $cid;
		$data['type'] = $type;
		$data['status'] = 'unread';
		$data['created'] = date('Y-m-d H:i:s');
		if ($this->db->insert('notifications', $data)) {
			return true;
		} else {
			return false;
		}
	}
	public function getLog($resultType = 'row', $cid = null, $type = null, $status = null, $checked = null)
	{
		$this->db->from('notifications');
		if (!empty($cid)) {
			$this->db->where('cid', $cid);
		}
		if (!empty($type)) {
			$this->db->where('type', $type);
		}
		if (!empty($status)) {
			$this->db->where('status', $status);
		}
		if (!empty($checked)) {
			$this->db->where('checked', $checked);
		}
		$query = $this->db->get();
		if ($resultType === 'row') {
			return $query->row();
		} else {
			return $query->result();
		}
	}
	public function getLogCount($cid = null, $type = null, $status = null, $checked = null)
	{
		$this->db->from('notifications');
		if (!empty($cid)) {
			$this->db->where('cid', $cid);
		}
		if (!empty($type)) {
			$this->db->where('type', $type);
		}
		if (!empty($status)) {
			$this->db->where('status', $status);
		}
		if (!empty($checked)) {
			$this->db->where('checked', $checked);
		}
		return $this->db->count_all_results();
	}
	public function search_properties($search_query) {
		// Trim and escape the search query to prevent SQL injection
		$search_query = trim($this->db->escape_str($search_query));
		// Search across multiple columns
		$this->db->like('title', $search_query);
		$this->db->or_like('description', $search_query);
		$this->db->or_like('location', $search_query);
		$this->db->or_like('property_id', $search_query);
		$this->db->or_like('price', $search_query);
		$this->db->or_like('property_size', $search_query);
		$this->db->or_like('year_built', $search_query);
		$this->db->or_like('bedrooms', $search_query);
		$this->db->or_like('bathrooms', $search_query);
		$this->db->or_like('garage', $search_query);
		$this->db->or_like('garage_size', $search_query);
		$this->db->or_like('project_type', $search_query);
		$this->db->or_like('property_type', $search_query);
		$this->db->or_like('property_status', $search_query);
		$this->db->or_like('deposit', $search_query);
		$this->db->or_like('last_remodel_year', $search_query);
		$this->db->or_like('pool_size', $search_query);
		$this->db->or_like('amenities', $search_query);
		$this->db->or_like('places_nearby', $search_query);
		$this->db->or_like('additional_rooms', $search_query);
		$this->db->or_like('equipment', $search_query);
		$this->db->or_like('for_status', $search_query);
		$this->db->or_like('ready_to_move', $search_query);
		$this->db->or_like('balcony', $search_query);
		$this->db->or_like('video', $search_query);
		$query = $this->db->get('property');
		return $query->result();
	}
	public function gc($cid, $btn = true)
	{
		$contentWithBtn = $this->getDataSingle('contents', $cid, 'cid', null)->content;
		if ($btn == true && isset($_SESSION['su'])) {
			$editBtn = '
			<button type="button" onClick="updateContent(\''.hashed($cid).'\')" class="editButton">
			<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" class="bi bi-pencil" viewBox="0 0 16 16">
			<path d="M12.146.146a.5.5 0 0 1 .708 0l3 3a.5.5 0 0 1 0 .708l-10 10a.5.5 0 0 1-.168.11l-5 2a.5.5 0 0 1-.65-.65l2-5a.5.5 0 0 1 .11-.168l10-10zm1.207 2.207L10.207 5.5 9 4.293l3.146-3.147 1.207 1.207zm-1.414 1.414L8.5 6.793 9.707 8l3.439-3.439-1.207-1.207zM1 13.5V15h1.5l5-5L6 8.5l-5 5z"/>
			</svg>
			Edit
			</button>';
			echo $contentWithBtn . '&nbsp;' . $editBtn;
		} else {
			return $contentWithBtn;
		}
	}
	// Fetch properties with filters and pagination
	public function get_filtered_properties($params = [], $offset, $limit) {
		$this->db->select('*');
		$this->db->from('property');
		// Apply filters if they exist
		if (!empty($params['property_type'])) {
			$this->db->where('property_type', $params['property_type']);
		}
		if (!empty($params['property_status'])) {
			$this->db->where('property_status', $params['property_status']);
		}
		if (!empty($params['bedrooms'])) {
			$this->db->where('bedrooms >=', (int) $params['bedrooms']);
		}
		if (!empty($params['bathrooms'])) {
			$this->db->where('bathrooms >=', (int) $params['bathrooms']);
		}
		if (!empty($params['location'])) {
			$this->db->like('location', $params['location']);
		}
		if (!empty($params['minbudget'])) {
			$this->db->where('price >=', (int) $params['minbudget']);
		}
		if (!empty($params['maxbudget'])) {
			$this->db->where('price <=', (int) $params['maxbudget']);
		}
		// Set limit and offset for pagination
		$this->db->limit($limit, $offset);
		// Execute the query
		$query = $this->db->get();
		return $query->result();
	}
	// Get total count for pagination
	public function count_filtered_properties($params = []) {
		$this->db->select('id');
		$this->db->from('property');
		// Apply filters if they exist
		if (!empty($params['property_type'])) {
			$this->db->where('property_type', $params['property_type']);
		}
		if (!empty($params['property_status'])) {
			$this->db->where('property_status', $params['property_status']);
		}
		if (!empty($params['bedrooms'])) {
			$this->db->where('bedrooms >=', (int) $params['bedrooms']);
		}
		if (!empty($params['bathrooms'])) {
			$this->db->where('bathrooms >=', (int) $params['bathrooms']);
		}
		if (!empty($params['location'])) {
			$this->db->like('location', $params['location']);
		}
		if (!empty($params['minbudget'])) {
			$this->db->where('price >=', (int) $params['minbudget']);
		}
		if (!empty($params['maxbudget'])) {
			$this->db->where('price <=', (int) $params['maxbudget']);
		}
		// Execute the query
		return $this->db->count_all_results();
	}
}
